# tBTC.py

A python client to interact with the [tbtc](https://tbtc.network/) protocol.

Erasure Protocol version: `1.1.0`


## Setup:
1. Create & activate virtulenv (python 3.6+)
2. Install the library using pypi. 

    ```
    pip install tbtc
    ```


## Development:
1. Clone & enter the repo. `git clone https://github.com/ankitchiplunkar/tbtc.py.git`
2. Install required libraries. `pip install -r requirements.txt`

## Testing:
1. Run the tests locally 

    ```pytest -vv tests/```